from django import forms
from django.core.exceptions import ValidationError

from pbs.report.models import (SummaryCompletionState, BurnImplementationState,
                               BurnClosureState, AreaAchievement)


class SummaryCompletionStateForm(forms.ModelForm):
    """
    Validates the completion status of the ePFP.
    """

    class Meta:
        model = SummaryCompletionState
        exclude = ('prescription',)


class PatchedModelForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super(PatchedModelForm, self).__init__(*args, **kwargs)
        # there is a bug in django's fields.NullBooleanField
        # if it gets custom choices, it always adds an extra
        # blank_choice '-----', so let's remove it (there is None choice
        # already)
        for field_key in self.fields:
            field = self.fields[field_key]
            if hasattr(field, 'choices'):
                if (len(field.choices) > 1 and field.choices[0][0] == '' and
                        field.choices[1][0] is None):
                    # we definitely don't need None and '' as two separate
                    # choices
                    field.choices = field.choices[1:]


class BurnImplementationStateForm(PatchedModelForm):
    """
    Validates the completion status of Part B of an ePFP.
    """
    class Meta:
        model = BurnImplementationState
        exclude = ('prescription',)


class BurnClosureStateForm(PatchedModelForm):
    class Meta:
        model = BurnClosureState
        exclude = ('prescription',)


class AreaAchievementForm(forms.ModelForm):
    def clean(self):
        """
        Test that if there is an ignition type, there also has to be treated
        area, burnt area, edging length and edging depth entered.
        """
        cleaned_data = super(AreaAchievementForm, self).clean()
        ignition_types = cleaned_data.get("ignition_types")

        if ignition_types:
            if not all([cleaned_data.get('area_treated'),
                        cleaned_data.get('area_estimate')]):
                raise ValidationError("You must fill in values for treated "
                                      "area and burnt area if you select an "
                                      "ignition type.")

        return cleaned_data

    class Meta:
        model = AreaAchievement
